@@ -8,15 +8,15 @@ pub enum OckamError {
     InvalidProof,
     ConsistencyError,
     ComplexEventsAreNotSupported,
-    EventIdDoesntMatch,
-    ProfileIdDoesntMatch,
+    EventIdDoesNotMatch,
+    ProfileIdDoesNotMatch,
     EmptyChange,
     ContactNotFound,
     EventNotFound,
     InvalidChainSequence,
     InvalidEventId,
-    AttestationRequesterDoesntMatch,
-    AttestationNonceDoesntMatch,
+    AttestationRequesterDoesNotMatch,
+    AttestationNonceDoesNotMatch,
     InvalidHubResponse,
     InvalidParameter,
     SecureChannelVerificationFailed,
